# coding: utf-8

# flake8: noqa
"""
    MMP Metadata

    This is a API for MMP Metadata  # noqa: E501

    The version of the OpenAPI document: 1.0.0-oas3
    Contact: st116848@stud.uni-stuttgart.de.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

# import models into model package
from mmp_metadata_client.models.artifact import Artifact
from mmp_metadata_client.models.dataset import Dataset
from mmp_metadata_client.models.executable import Executable
from mmp_metadata_client.models.execution import Execution
from mmp_metadata_client.models.experiment import Experiment
from mmp_metadata_client.models.metrics import Metrics
from mmp_metadata_client.models.model import Model
from mmp_metadata_client.models.pair import Pair
from mmp_metadata_client.models.run import Run
from mmp_metadata_client.models.trace import Trace
from mmp_metadata_client.models.trace_artifacts import TraceArtifacts
from mmp_metadata_client.models.trace_execution_types import TraceExecutionTypes



# coding: utf-8

"""
    MMP Metadata

    This is a API for MMP Metadata  # noqa: E501

    The version of the OpenAPI document: 1.0.0-oas3
    Contact: st116848@stud.uni-stuttgart.de.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from mmp_metadata_client.api_client import ApiClient
from mmp_metadata_client.exceptions import (
    ApiTypeError,
    ApiValueError
)


class ExperimentApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def add_experiment(self, **kwargs):  # noqa: E501
        """adds an experiment  # noqa: E501

        Adds an experiment  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.add_experiment(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param Experiment experiment: Experiment item to add
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Experiment
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.add_experiment_with_http_info(**kwargs)  # noqa: E501

    def add_experiment_with_http_info(self, **kwargs):  # noqa: E501
        """adds an experiment  # noqa: E501

        Adds an experiment  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.add_experiment_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param Experiment experiment: Experiment item to add
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(Experiment, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['experiment']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method add_experiment" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'experiment' in local_var_params:
            body_params = local_var_params['experiment']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/experiments', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Experiment',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_experiment_by_id(self, experiment, **kwargs):  # noqa: E501
        """experiment by id  # noqa: E501

        Return one experiemtn by `id`  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_experiment_by_id(experiment, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str experiment: The experiemnt's id (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Experiment
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.get_experiment_by_id_with_http_info(experiment, **kwargs)  # noqa: E501

    def get_experiment_by_id_with_http_info(self, experiment, **kwargs):  # noqa: E501
        """experiment by id  # noqa: E501

        Return one experiemtn by `id`  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_experiment_by_id_with_http_info(experiment, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str experiment: The experiemnt's id (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(Experiment, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['experiment']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_experiment_by_id" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'experiment' is set
        if ('experiment' not in local_var_params or
                local_var_params['experiment'] is None):
            raise ApiValueError("Missing the required parameter `experiment` when calling `get_experiment_by_id`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'experiment' in local_var_params:
            path_params['experiment'] = local_var_params['experiment']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/experiments/{experiment}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Experiment',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_experiments(self, **kwargs):  # noqa: E501
        """list of experiments  # noqa: E501

        Return list of experiemtns  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_experiments(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: list[Experiment]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.get_experiments_with_http_info(**kwargs)  # noqa: E501

    def get_experiments_with_http_info(self, **kwargs):  # noqa: E501
        """list of experiments  # noqa: E501

        Return list of experiemtns  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_experiments_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(list[Experiment], status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = []  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_experiments" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/experiments', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[Experiment]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    MMP Metadata

    This is a API for MMP Metadata  # noqa: E501

    The version of the OpenAPI document: 1.0.0-oas3
    Contact: st116848@stud.uni-stuttgart.de.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


class Pair(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'value1': 'str',
        'value2': 'str'
    }

    attribute_map = {
        'value1': 'value1',
        'value2': 'value2'
    }

    def __init__(self, value1=None, value2=None):  # noqa: E501
        """Pair - a model defined in OpenAPI"""  # noqa: E501

        self._value1 = None
        self._value2 = None
        self.discriminator = None

        if value1 is not None:
            self.value1 = value1
        if value2 is not None:
            self.value2 = value2

    @property
    def value1(self):
        """Gets the value1 of this Pair.  # noqa: E501


        :return: The value1 of this Pair.  # noqa: E501
        :rtype: str
        """
        return self._value1

    @value1.setter
    def value1(self, value1):
        """Sets the value1 of this Pair.


        :param value1: The value1 of this Pair.  # noqa: E501
        :type: str
        """

        self._value1 = value1

    @property
    def value2(self):
        """Gets the value2 of this Pair.  # noqa: E501


        :return: The value2 of this Pair.  # noqa: E501
        :rtype: str
        """
        return self._value2

    @value2.setter
    def value2(self, value2):
        """Sets the value2 of this Pair.


        :param value2: The value2 of this Pair.  # noqa: E501
        :type: str
        """

        self._value2 = value2

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Pair):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    MMP Metadata

    This is a API for MMP Metadata  # noqa: E501

    The version of the OpenAPI document: 1.0.0-oas3
    Contact: st116848@stud.uni-stuttgart.de.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


class Model(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'str',
        'name': 'str',
        'version': 'str',
        'kind': 'str',
        'description': 'str',
        'create_time': 'datetime',
        'uri': 'str',
        'annotations': 'dict(str, str)',
        'type': 'str',
        'framework': 'Pair',
        'hyper_parameters': 'dict(str, str)',
        'tags': 'list[str]',
        'input_schema': 'str',
        'output_schema': 'str'
    }

    attribute_map = {
        'id': 'id',
        'name': 'name',
        'version': 'version',
        'kind': 'kind',
        'description': 'description',
        'create_time': 'createTime',
        'uri': 'uri',
        'annotations': 'annotations',
        'type': 'type',
        'framework': 'framework',
        'hyper_parameters': 'hyperParameters',
        'tags': 'tags',
        'input_schema': 'inputSchema',
        'output_schema': 'outputSchema'
    }

    def __init__(self, id=None, name=None, version=None, kind='model', description=None, create_time=None, uri=None, annotations=None, type=None, framework=None, hyper_parameters=None, tags=None, input_schema=None, output_schema=None):  # noqa: E501
        """Model - a model defined in OpenAPI"""  # noqa: E501

        self._id = None
        self._name = None
        self._version = None
        self._kind = None
        self._description = None
        self._create_time = None
        self._uri = None
        self._annotations = None
        self._type = None
        self._framework = None
        self._hyper_parameters = None
        self._tags = None
        self._input_schema = None
        self._output_schema = None
        self.discriminator = None

        if id is not None:
            self.id = id
        self.name = name
        self.version = version
        self.kind = kind
        if description is not None:
            self.description = description
        if create_time is not None:
            self.create_time = create_time
        if uri is not None:
            self.uri = uri
        if annotations is not None:
            self.annotations = annotations
        if type is not None:
            self.type = type
        if framework is not None:
            self.framework = framework
        if hyper_parameters is not None:
            self.hyper_parameters = hyper_parameters
        if tags is not None:
            self.tags = tags
        if input_schema is not None:
            self.input_schema = input_schema
        if output_schema is not None:
            self.output_schema = output_schema

    @property
    def id(self):
        """Gets the id of this Model.  # noqa: E501


        :return: The id of this Model.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this Model.


        :param id: The id of this Model.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def name(self):
        """Gets the name of this Model.  # noqa: E501


        :return: The name of this Model.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this Model.


        :param name: The name of this Model.  # noqa: E501
        :type: str
        """
        if name is None:
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    @property
    def version(self):
        """Gets the version of this Model.  # noqa: E501


        :return: The version of this Model.  # noqa: E501
        :rtype: str
        """
        return self._version

    @version.setter
    def version(self, version):
        """Sets the version of this Model.


        :param version: The version of this Model.  # noqa: E501
        :type: str
        """
        if version is None:
            raise ValueError("Invalid value for `version`, must not be `None`")  # noqa: E501

        self._version = version

    @property
    def kind(self):
        """Gets the kind of this Model.  # noqa: E501


        :return: The kind of this Model.  # noqa: E501
        :rtype: str
        """
        return self._kind

    @kind.setter
    def kind(self, kind):
        """Sets the kind of this Model.


        :param kind: The kind of this Model.  # noqa: E501
        :type: str
        """
        if kind is None:
            raise ValueError("Invalid value for `kind`, must not be `None`")  # noqa: E501

        self._kind = kind

    @property
    def description(self):
        """Gets the description of this Model.  # noqa: E501


        :return: The description of this Model.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this Model.


        :param description: The description of this Model.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def create_time(self):
        """Gets the create_time of this Model.  # noqa: E501


        :return: The create_time of this Model.  # noqa: E501
        :rtype: datetime
        """
        return self._create_time

    @create_time.setter
    def create_time(self, create_time):
        """Sets the create_time of this Model.


        :param create_time: The create_time of this Model.  # noqa: E501
        :type: datetime
        """

        self._create_time = create_time

    @property
    def uri(self):
        """Gets the uri of this Model.  # noqa: E501


        :return: The uri of this Model.  # noqa: E501
        :rtype: str
        """
        return self._uri

    @uri.setter
    def uri(self, uri):
        """Sets the uri of this Model.


        :param uri: The uri of this Model.  # noqa: E501
        :type: str
        """

        self._uri = uri

    @property
    def annotations(self):
        """Gets the annotations of this Model.  # noqa: E501


        :return: The annotations of this Model.  # noqa: E501
        :rtype: dict(str, str)
        """
        return self._annotations

    @annotations.setter
    def annotations(self, annotations):
        """Sets the annotations of this Model.


        :param annotations: The annotations of this Model.  # noqa: E501
        :type: dict(str, str)
        """

        self._annotations = annotations

    @property
    def type(self):
        """Gets the type of this Model.  # noqa: E501


        :return: The type of this Model.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this Model.


        :param type: The type of this Model.  # noqa: E501
        :type: str
        """

        self._type = type

    @property
    def framework(self):
        """Gets the framework of this Model.  # noqa: E501


        :return: The framework of this Model.  # noqa: E501
        :rtype: Pair
        """
        return self._framework

    @framework.setter
    def framework(self, framework):
        """Sets the framework of this Model.


        :param framework: The framework of this Model.  # noqa: E501
        :type: Pair
        """

        self._framework = framework

    @property
    def hyper_parameters(self):
        """Gets the hyper_parameters of this Model.  # noqa: E501


        :return: The hyper_parameters of this Model.  # noqa: E501
        :rtype: dict(str, str)
        """
        return self._hyper_parameters

    @hyper_parameters.setter
    def hyper_parameters(self, hyper_parameters):
        """Sets the hyper_parameters of this Model.


        :param hyper_parameters: The hyper_parameters of this Model.  # noqa: E501
        :type: dict(str, str)
        """

        self._hyper_parameters = hyper_parameters

    @property
    def tags(self):
        """Gets the tags of this Model.  # noqa: E501


        :return: The tags of this Model.  # noqa: E501
        :rtype: list[str]
        """
        return self._tags

    @tags.setter
    def tags(self, tags):
        """Sets the tags of this Model.


        :param tags: The tags of this Model.  # noqa: E501
        :type: list[str]
        """

        self._tags = tags

    @property
    def input_schema(self):
        """Gets the input_schema of this Model.  # noqa: E501


        :return: The input_schema of this Model.  # noqa: E501
        :rtype: str
        """
        return self._input_schema

    @input_schema.setter
    def input_schema(self, input_schema):
        """Sets the input_schema of this Model.


        :param input_schema: The input_schema of this Model.  # noqa: E501
        :type: str
        """

        self._input_schema = input_schema

    @property
    def output_schema(self):
        """Gets the output_schema of this Model.  # noqa: E501


        :return: The output_schema of this Model.  # noqa: E501
        :rtype: str
        """
        return self._output_schema

    @output_schema.setter
    def output_schema(self, output_schema):
        """Sets the output_schema of this Model.


        :param output_schema: The output_schema of this Model.  # noqa: E501
        :type: str
        """

        self._output_schema = output_schema

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Model):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



from __future__ import absolute_import

# flake8: noqa

# import apis into api package
from mmp_metadata_client.api.artifact_api import ArtifactApi
from mmp_metadata_client.api.execution_api import ExecutionApi
from mmp_metadata_client.api.experiment_api import ExperimentApi
from mmp_metadata_client.api.run_api import RunApi
from mmp_metadata_client.api.trace_api import TraceApi



# coding: utf-8

"""
    MMP Metadata

    This is a API for MMP Metadata  # noqa: E501

    The version of the OpenAPI document: 1.0.0-oas3
    Contact: st116848@stud.uni-stuttgart.de.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import mmp_metadata_client
from mmp_metadata_client.api.trace_api import TraceApi  # noqa: E501
from mmp_metadata_client.rest import ApiException


class TestTraceApi(unittest.TestCase):
    """TraceApi unit test stubs"""

    def setUp(self):
        self.api = mmp_metadata_client.api.trace_api.TraceApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_get_trace_by_experiment(self):
        """Test case for get_trace_by_experiment

        one specific trace  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    MMP Metadata

    This is a API for MMP Metadata  # noqa: E501

    The version of the OpenAPI document: 1.0.0-oas3
    Contact: st116848@stud.uni-stuttgart.de.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import openapi_client
from openapi_client.models.executable import Executable  # noqa: E501
from openapi_client.rest import ApiException


class TestExecutable(unittest.TestCase):
    """Executable unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testExecutable(self):
        """Test Executable"""
        # FIXME: construct object with mandatory attributes with example values
        # model = openapi_client.models.executable.Executable()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
